@@ -50,7 +50,7 @@
  */
 
 /*
-   Copyright (C) 1997-2023 by Erik Nolf
+   Copyright (C) 1997-2024 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -1219,21 +1219,37 @@ void MdcRenameFile(char *name)
 }
 
 /* always check for both path delimiters */
+/* return the very last in case of mixes */
 char *MdcGetLastPathDelim(char *path)
 {
-  char *p=NULL;
+  char *d1=NULL, *d2=NULL;
 
-  if (path == NULL) return NULL;
+  if (path == NULL) return(NULL);
 
-  p = (char *)strrchr(path,'/');
-  if (p != NULL) return(p);
+  d1 = (char *)strrchr(path,'/');
+  d2 = (char *)strrchr(path,'\\');
 
-  p = (char *)strrchr(path,'\\');
-  return(p);
+  /* mixed path delimiters found */
+  if ( (d1 != NULL) && (d2 != NULL) ) {
+    /* which one is closest to end */
+    if (strlen(d1) < strlen(d2)) {
+      return(d1);
+    }else{
+      return(d2);
+    }
+  }
+
+  /* only forward  slashes */
+  if (d1 != NULL) return(d1);
+
+  /* just backward slashes */
+  if (d2 != NULL) return(d2);
+
+  /* without path delimiters */
+  return(NULL);
 
 }
 
-
 void MdcMySplitPath(char path[], char **dir, char **fname)
 {
   char *p=NULL;
