@@ -17,7 +17,7 @@
  */
 
 /*
-   Copyright (C) 1997-2023 by Erik Nolf
+   Copyright (C) 1997-2024 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -149,7 +149,7 @@ char *MdcStackSlices(void)
 
        if (!MdcGetStructID(ofi,nr_of_images)) {
          MdcCleanUpFI(ofi); MdcCleanUpFI(ifi);
-         return("stack slices : Couldn't alloc output ING_DATA structs");
+         return("stack slices : Couldn't alloc output IMG_DATA structs");
        }
 
        /* remember time_frame_duration */
